# Configurations

Templates for various different issue types are defined in this directory
and a pull request template is defined as ``../pull_request_template.md``. Adding,
removing, and modifying these templates to suit the needs of your project is encouraged.

For more information about these templates, look here: https://lincc-ppt.readthedocs.io/en/latest/practices/issue_pr_templating.html

Or if you still have questions contact us: https://lincc-ppt.readthedocs.io/en/latest/source/contact.html